@@ -41,7 +41,7 @@ class SamplePlugin(analysis_plugin.AnalysisPlugin):
         self.thread_manager = ThreadManager(self)
         try:
             self.rope_project = codeeditor.get_rope_project()
-        except IOError:  # Might happen when frozen
+        except (IOError, AttributeError):  # Might happen when frozen
             self.rope_project = None
 
         data_path = QDesktopServices.storageLocation(
@@ -399,4 +399,4 @@ class SamplePlugin(analysis_plugin.AnalysisPlugin):
 
     def _current_editor_changed(self, index):
         editor = self.tabs.widget(index)
-        self.find_widget.set_editor(editor)
\ No newline at end of file
+        self.find_widget.set_editor(editor)
